@@ -12,7 +12,7 @@ pub struct PCG32 {
 
 impl PCG32 {
     pub fn seed(initstate: u64, initseq: u64) -> Self {
-        let mut rng = PCG32 {
+        let mut rng = Self {
             state: 0,
             inc: (initseq << 1) | 1,
         };
@@ -23,7 +23,7 @@ impl PCG32 {
     }
 
     pub fn default() -> Self {
-        PCG32::seed(0x853c49e6748fea9b, 0xda3e39cb94b95bdb)
+        Self::seed(0x853c49e6748fea9b, 0xda3e39cb94b95bdb)
     }
 
     pub fn next_u32(&mut self) -> u32 {
