@@ -3,7 +3,7 @@
 #[macro_export]
 macro_rules! bench_func {
     ($name: ident, $desc: expr, op => $func: ident, from => $from: expr) => {
-        #[allow(unsafe_code)] // just benchmarking code
+        #[allow(unsafe_code, clippy::undocumented_unsafe_blocks)] // just benchmarking code
         pub(crate) fn $name(c: &mut Criterion) {
             const SIZE: usize = 1 << 13;
             let mut rng = support::PCG32::default();
@@ -28,7 +28,7 @@ macro_rules! bench_func {
 #[macro_export]
 macro_rules! bench_unop {
     ($name: ident, $desc: expr, op => $unop: ident, from => $from: expr) => {
-        #[allow(unsafe_code)] // just benchmarking code
+        #[allow(unsafe_code, clippy::undocumented_unsafe_blocks)] // just benchmarking code
         pub(crate) fn $name(c: &mut Criterion) {
             const SIZE: usize = 1 << 13;
             let mut rng = support::PCG32::default();
@@ -53,7 +53,7 @@ macro_rules! bench_unop {
 #[macro_export]
 macro_rules! bench_binop {
     ($name: ident, $desc: expr, op => $binop: ident, from1 => $from1:expr, from2 => $from2:expr) => {
-        #[allow(unsafe_code)] // just benchmarking code
+        #[allow(unsafe_code, clippy::undocumented_unsafe_blocks)] // just benchmarking code
         pub(crate) fn $name(c: &mut Criterion) {
             const SIZE: usize = 1 << 13;
             let mut rng = support::PCG32::default();
@@ -83,7 +83,7 @@ macro_rules! bench_binop {
 #[macro_export]
 macro_rules! bench_trinop {
     ($name: ident, $desc: expr, op => $trinop: ident, from1 => $from1:expr, from2 => $from2:expr, from3 => $from3:expr) => {
-        #[allow(unsafe_code)] // just benchmarking code
+        #[allow(unsafe_code, clippy::undocumented_unsafe_blocks)] // just benchmarking code
         pub(crate) fn $name(c: &mut Criterion) {
             const SIZE: usize = 1 << 13;
             let mut rng = support::PCG32::default();
