@@ -52,6 +52,14 @@ impl BoundingBox {
         Self { min, max }
     }
 
+    #[inline]
+    pub fn from_min_size(min: Vec3, size: Vec3) -> Self {
+        Self {
+            min,
+            max: min + size,
+        }
+    }
+
     /// Create a bounding box from a center position and a size.
     pub fn from_center_size(center: Vec3, size: Vec3) -> Self {
         Self::from_min_max(center - 0.5 * size, center + 0.5 * size)
@@ -127,20 +135,33 @@ impl BoundingBox {
         self.min.is_nan() || self.max.is_nan()
     }
 
+    #[cfg(not(target_arch = "spirv"))]
     /// The eight corners of this bounding box.
     pub fn corners(&self) -> [Vec3; 8] {
         [
-            Vec3::new(self.min.x, self.min.y, self.min.z),
+            self.min,
             Vec3::new(self.min.x, self.min.y, self.max.z),
             Vec3::new(self.min.x, self.max.y, self.min.z),
             Vec3::new(self.min.x, self.max.y, self.max.z),
             Vec3::new(self.max.x, self.min.y, self.min.z),
             Vec3::new(self.max.x, self.min.y, self.max.z),
             Vec3::new(self.max.x, self.max.y, self.min.z),
-            Vec3::new(self.max.x, self.max.y, self.max.z),
+            self.max,
         ]
     }
 
+    /// The minimum radius of a sphere, centered at the origin, fully containing the box.
+    ///
+    /// Requires a well-formed box for the result to be valid.
+    #[cfg(not(target_arch = "spirv"))]
+    pub fn bounding_sphere_radius(&self) -> f32 {
+        let mut max_dist_square = 0.0f32;
+        for corner in self.corners() {
+            max_dist_square = max_dist_square.max(corner.length_squared());
+        }
+        max_dist_square.sqrt()
+    }
+
     /// The twelve edges of this bounding box.
     pub fn edges(&self) -> [[Vec3; 2]; 12] {
         use glam::vec3;
