@@ -41,10 +41,7 @@ pub struct ColorRgba8(pub [u8; 4]);
 
 impl From<ColorRgba8> for u32 {
     fn from(c: ColorRgba8) -> Self {
-        (Self::from(c.0[0]) << 24)
-            | (Self::from(c.0[1]) << 16)
-            | (Self::from(c.0[2]) << 8)
-            | Self::from(c.0[3])
+        (c.0[0] as u32) << 24 | (c.0[1] as u32) << 16 | (c.0[2] as u32) << 8 | c.0[3] as u32
     }
 }
 
