@@ -1,5 +1,4 @@
-use super::prelude::*;
-use super::{vec2, Vec2};
+use super::{prelude::*, vec2, Vec2};
 
 #[cfg(target_arch = "spirv")]
 use num_traits::Float;
@@ -9,26 +8,33 @@ use num_traits::Float;
 /// Adds additional functionality to [`Vec2`] that [`glam`] doesn't have.
 pub trait Vec2Ext {
     /// `x: cos(angle), y: sin(angle)` (in radians)
+    #[must_use]
     fn from_angle(angle: f32) -> Self;
 
     /// Angle of the vector: `y.atan2(x)`
+    #[must_use]
     fn angle(&self) -> f32;
 
     /// For element `i` of `self`, return `v[i].trunc()`
+    #[must_use]
     fn trunc(self) -> Self;
 
     /// For element `i` of the return value, returns 0.0 if `value[i] < self[i]` and 1.0 otherwise.
     ///
     /// Similar to glsl's step(edge, x), which translates into edge.step(x)
+    #[must_use]
     fn step(self, value: Self) -> Self;
 
     /// Selects between `true` and `false` based on the result of `value[i] < self[i]`
+    #[must_use]
     fn step_select(self, value: Self, tru: Self, fals: Self) -> Self;
 
     /// Return only the fractional parts of each component.
+    #[must_use]
     fn fract(self) -> Self;
 
     /// Clamp all components of `self` to the range `[0.0, 1.0]`
+    #[must_use]
     fn saturate(self) -> Self;
 }
 
