@@ -1,5 +1,4 @@
-use super::prelude::*;
-use super::{vec3, Vec3};
+use super::{prelude::*, vec3, Vec3};
 
 #[cfg(target_arch = "spirv")]
 use num_traits::Float;
@@ -9,29 +8,37 @@ use num_traits::Float;
 /// Adds additional functionality to [`Vec3`] that [`glam`] doesn't have.
 pub trait Vec3Ext {
     /// For element `i` of `self`, return `v[i].trunc()`
+    #[must_use]
     fn trunc(self) -> Self;
 
     /// For element `i` of the return value, returns 0.0 if `value[i] < self[i]` and 1.0 otherwise.
     ///
     /// Similar to glsl's step(edge, x), which translates into edge.step(x)
+    #[must_use]
     fn step(self, value: Self) -> Self;
 
     /// Selects between `true` and `false` based on the result of `value[i] < self[i]`
+    #[must_use]
     fn step_select(self, value: Self, tru: Self, fals: Self) -> Self;
 
     /// Return only the fractional parts of each component.
+    #[must_use]
     fn fract(self) -> Self;
 
     /// Clamp all components of `self` to the range `[0.0, 1.0]`
+    #[must_use]
     fn saturate(self) -> Self;
 
     /// Square root of all three components.
+    #[must_use]
     fn sqrt(self) -> Self;
 
     /// Natural logarithm of all three components.
+    #[must_use]
     fn ln(self) -> Self;
 
     /// The reflection of a incident vector and surface normal.
+    #[must_use]
     fn reflect(self, normal: Self) -> Self;
 }
 
@@ -42,7 +49,7 @@ impl Vec3Ext for Vec3 {
         vec3(self.x.trunc(), self.y.trunc(), self.z.trunc())
     }
 
-    fn step(self, value: Vec3) -> Self {
+    fn step(self, value: Self) -> Self {
         vec3(
             self.x.step(value.x),
             self.y.step(value.y),
@@ -74,7 +81,7 @@ impl Vec3Ext for Vec3 {
         vec3(self.x.ln(), self.y.ln(), self.z.ln())
     }
 
-    fn reflect(self, normal: Vec3) -> Self {
+    fn reflect(self, normal: Self) -> Self {
         self - 2.0 * normal * self.dot(normal)
     }
 }
